@@ -1,7 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -23,78 +19,77 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/union.h>
 #include <glibtop/sysdeps.h>
+#include <glibtop/init_hooks.h>
 
-glibtop_init_func_t _glibtop_init_hook_p [] = {
+const _glibtop_init_func_t _glibtop_init_hook_p [] = {
 #if GLIBTOP_SUID_CPU
-    glibtop_init_cpu_p,
+	_glibtop_init_cpu_p,
 #endif
 #if GLIBTOP_SUID_MEM
-    glibtop_init_mem_p,
+	_glibtop_init_mem_p,
 #endif
 #if GLIBTOP_SUID_SWAP
-    glibtop_init_swap_p,
+	_glibtop_init_swap_p,
 #endif
 #if GLIBTOP_SUID_UPTIME
-    glibtop_init_uptime_p,
+	_glibtop_init_uptime_p,
 #endif
 #if GLIBTOP_SUID_LOADAVG
-    glibtop_init_loadavg_p,
+	_glibtop_init_loadavg_p,
 #endif
 #if GLIBTOP_SUID_SHM_LIMITS
-    glibtop_init_shm_limits_p,
+	_glibtop_init_shm_limits_p,
 #endif
 #if GLIBTOP_SUID_MSG_LIMITS
-    glibtop_init_msg_limits_p,
+	_glibtop_init_msg_limits_p,
 #endif
 #if GLIBTOP_SUID_SEM_LIMITS
-    glibtop_init_sem_limits_p,
+	_glibtop_init_sem_limits_p,
 #endif
 #if GLIBTOP_SUID_PROCLIST
-    glibtop_init_proclist_p,
+	_glibtop_init_proclist_p,
 #endif
 #if GLIBTOP_SUID_PROC_STATE
-    glibtop_init_proc_state_p,
+	_glibtop_init_proc_state_p,
 #endif
 #if GLIBTOP_SUID_PROC_UID
-    glibtop_init_proc_uid_p,
+	_glibtop_init_proc_uid_p,
 #endif
 #if GLIBTOP_SUID_PROC_MEM
-    glibtop_init_proc_mem_p,
+	_glibtop_init_proc_mem_p,
 #endif
 #if GLIBTOP_SUID_PROC_TIME
-    glibtop_init_proc_time_p,
+	_glibtop_init_proc_time_p,
 #endif
 #if GLIBTOP_SUID_PROC_SIGNAL
-    glibtop_init_proc_signal_p,
+	_glibtop_init_proc_signal_p,
 #endif
 #if GLIBTOP_SUID_PROC_KERNEL
-    glibtop_init_proc_kernel_p,
+	_glibtop_init_proc_kernel_p,
 #endif
 #if GLIBTOP_SUID_PROC_SEGMENT
-    glibtop_init_proc_segment_p,
+	_glibtop_init_proc_segment_p,
 #endif
 #if GLIBTOP_SUID_PROC_ARGS
-    glibtop_init_proc_args_p,
+	_glibtop_init_proc_args_p,
 #endif
 #if GLIBTOP_SUID_PROC_MAP
-    glibtop_init_proc_map_p,
+	_glibtop_init_proc_map_p,
 #endif
-#if GLIBTOP_SUID_NETINFO
-    glibtop_init_netinfo_p,
+#if GLIBTOP_SUID_NETLOAD
+	_glibtop_init_netload_p,
 #endif
-#if GLIBTOP_SUID_NETINFO
-    glibtop_init_netinfo_p,
-#endif
-#if GLIBTOP_SUID_INTERFACE_NAMES
-    glibtop_init_interface_names_p,
+#if GLIBTOP_SUID_NETLIST
+	_glibtop_init_netlist_p,
 #endif
 #if GLIBTOP_SUID_PPP
-    glibtop_init_ppp_p,
+	_glibtop_init_ppp_p,
 #endif
-    NULL
+	NULL
 };
 
