@@ -1,5 +1,3 @@
-/* $Id: procsegment.c,v 1.3 1999/02/23 11:46:59 martin Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procsegment.h>
@@ -32,7 +31,7 @@ static const unsigned long _glibtop_sysdeps_proc_segment = 0;
 /* Init function. */
 
 void
-glibtop_init_proc_segment_p (glibtop *server)
+_glibtop_init_proc_segment_p (glibtop *server)
 {
 	server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment;
 }
@@ -44,6 +43,6 @@ glibtop_get_proc_segment_p (glibtop *server, glibtop_proc_segment *buf,
 			    pid_t pid)
 {
 	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_SEGMENT, 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proc_segment));
 }
